[142056] JSF library referenced in a web project does not act as true reference
[156784] JSF Library References are not stored in the project .settings folder
[164165] Exception logged on deploy flag change in JSF library
[178291] JSF Library jars not copied when project location is not default
[154573] The FacesServlet class name is hardcoded to javax.faces.webapp.FacesServlet
Facet install page UI Cleanup
Removed JSF Library Reference Page - must now Java Build Path + j2ee Module dependencies
New Wizard: New JSF Library --> JSF Library
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/AllTests.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/AllTests.java
index bc4397c..6daa22b 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/AllTests.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/AllTests.java
@@ -13,7 +13,6 @@
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
-import org.eclipse.jst.jsf.core.tests.jsflibraryconfig.J2EEModuleDependencyDelegateTestCases;
 import org.eclipse.jst.jsf.core.tests.jsflibraryconfig.JSFLibraryConfigDialogSettingDataTestCases;
 import org.eclipse.jst.jsf.core.tests.jsflibraryconfig.JSFLibraryConfigModelTestCases;
 import org.eclipse.jst.jsf.core.tests.jsflibraryconfig.JSFLibraryRegistryUtilTestCases;
@@ -56,7 +55,6 @@
 		
 		suite.addTestSuite(JSFFacetInstallDataModelProviderTestCases.class);
 		
-		suite.addTestSuite(J2EEModuleDependencyDelegateTestCases.class);
 		suite.addTestSuite(JSFLibraryConfigDialogSettingDataTestCases.class);
 		suite.addTestSuite(JSFProjectLibraryReferenceTestCases.class);
 		suite.addTestSuite(JSFLibraryConfigModelTestCases.class);
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/J2EEModuleDependencyDelegateTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/J2EEModuleDependencyDelegateTestCases.java
deleted file mode 100644
index 80557e1..0000000
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/J2EEModuleDependencyDelegateTestCases.java
+++ /dev/null
@@ -1,55 +0,0 @@
-package org.eclipse.jst.jsf.core.tests.jsflibraryconfig;
-
-import junit.framework.Assert;
-import junit.framework.TestCase;
-
-import org.eclipse.core.resources.IProject;
-import org.eclipse.core.runtime.NullProgressMonitor;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.J2EEModuleDependencyDelegate;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigDialogSettingData;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigModel;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfiglModelSource;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigModel.JSFLibraryConfigModelFactory;
-import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibrary;
-import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibraryRegistry;
-import org.eclipse.jst.jsf.core.tests.util.JSFCoreUtilHelper;
-
-public class J2EEModuleDependencyDelegateTestCases extends TestCase {	
-	private static final String PROJ_NAME = "_TEST_CFGMODULEDEPENDENCY_PROJECT";
-	private IProject project; 
-
-	public J2EEModuleDependencyDelegateTestCases(String name) {
-		super(name);
-	}
-
-	protected void setUp() throws Exception {
-		super.setUp();
-		
-		JSFCoreUtilHelper.createJSFLibraryRegistry();
-		project = JSFCoreUtilHelper.createWebProject(PROJ_NAME);		
-	}
-
-	protected void tearDown() throws Exception {
-		super.tearDown();
-		
-		project = null;		
-	}
-
-	public void testJ2EEModuleDependencyDelegate() {
-		J2EEModuleDependencyDelegate dep = new J2EEModuleDependencyDelegate(project);
-		Assert.assertNotNull(dep);
-
-		// Test updateProjectDependencies method()
-		JSFLibraryRegistry libReg = JSFCoreUtilHelper.getJSFLibraryRegistryFromJSFCorePlugin();
-
-		String[] compLibs = new String[1];
-		JSFLibrary lib = (JSFLibrary)libReg.getNonImplJSFLibraries().get(0);
-		compLibs[0] = lib.getID() + ":" + "true";	// deployed
-		
-		JSFLibraryConfiglModelSource modelsrc = new JSFLibraryConfigDialogSettingData(true, compLibs);
-		JSFLibraryConfigModel model = JSFLibraryConfigModelFactory.createInstance(modelsrc);
-		dep.updateProjectDependencies(model, new NullProgressMonitor());
-		// Validate updated dependencies??
-	}
-	
-}
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryConfigModelTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryConfigModelTestCases.java
index c39b7a1..1d8f0f4 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryConfigModelTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryConfigModelTestCases.java
@@ -12,7 +12,7 @@
 import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigDialogSettingData;
 import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigModel;
 import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfiglModelSource;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFProjectLibraryReference;
+import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryReference;
 import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryConfigModel.JSFLibraryConfigModelFactory;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibrary;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibraryRegistry;
@@ -75,7 +75,7 @@
 		JSFLibraryConfigModel model = JSFLibraryConfigModelFactory.createInstance(modelSrc);
 
 		JSFLibraryRegistry libReg = JSFCoreUtilHelper.getJSFLibraryRegistryFromJSFCorePlugin();
-		JSFProjectLibraryReference libImplRef = model.getCurrentJSFImplementationLibrarySelection();
+		JSFLibraryReference libImplRef = model.getCurrentJSFImplementationLibrarySelection();
 		Assert.assertNotNull(libImplRef);
 		Assert.assertTrue(libReg.getDefaultImplementation().getID().equals(libImplRef.getID()));
 	}
@@ -88,7 +88,7 @@
 		
 		Assert.assertTrue(lstCompRef.size() == 1);
 		
-		JSFProjectLibraryReference libCompRef = (JSFProjectLibraryReference) lstCompRef.get(0);  
+		JSFLibraryReference libCompRef = (JSFLibraryReference) lstCompRef.get(0);  
 		Assert.assertNotNull(libCompRef);
 		Assert.assertTrue(libCompRef.isSelected());
 		Assert.assertTrue(libCompRef.isCheckedToBeDeployed());
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryRegistryUtilTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryRegistryUtilTestCases.java
index 2aa4026..70990ed 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryRegistryUtilTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFLibraryRegistryUtilTestCases.java
@@ -1,7 +1,7 @@
 package org.eclipse.jst.jsf.core.tests.jsflibraryconfig;
 
 import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryRegistryUtil;
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFProjectLibraryReference;
+import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryReference;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibrary;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibraryRegistry;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibraryRegistryFactory;
@@ -36,24 +36,24 @@
 	}
 
 	public void testGetDefaultJSFImplementationLibrary() {
-		JSFProjectLibraryReference dftImplLib = libUtilInstance.getDefaultJSFImplementationLibrary();
+		JSFLibraryReference dftImplLib = libUtilInstance.getDefaultJSFImplementationLibrary();
 		Assert.assertNotNull(dftImplLib);
 		Assert.assertEquals(libReg.getDefaultImplementation().getID(), dftImplLib.getID());
 	}
 
 	public void testGetJSFLibryReferencebyID() {
-		JSFProjectLibraryReference lib = libUtilInstance.getJSFLibryReferencebyID(libReg.getDefaultImplementationID());
+		JSFLibraryReference lib = libUtilInstance.getJSFLibraryReferencebyID(libReg.getDefaultImplementationID());
 		Assert.assertNotNull(lib);
 		Assert.assertEquals(libReg.getDefaultImplementation().getID(), lib.getID());
 	}
 
 	public void testAddJSFLibrary() {
 		JSFLibrary jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createJSFLibrary();		
-		jsfLib.setID("124365879");
+//		jsfLib.setID("124365879");
 		jsfLib.setName("A_COMP_LIB");
 		jsfLib.setImplementation(false);
 				
-		JSFProjectLibraryReference jsfLibRef = new JSFProjectLibraryReference(jsfLib, 
+		JSFLibraryReference jsfLibRef = new JSFLibraryReference(jsfLib, 
 	   											   			false,	// selected 
 	   											   			false);	// to be deployed
 		Assert.assertTrue(libReg.getNonImplJSFLibraries().size() == numCompLibs);
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/ArchiveFileTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/ArchiveFileTestCases.java
index 3a8722d..be0c404 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/ArchiveFileTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/ArchiveFileTestCases.java
@@ -50,7 +50,7 @@
 
 	public void testArchiveFile() {		
 		JSFLibrary jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createJSFLibrary();		
-		jsfLib.setID("Myfaces");
+//		jsfLib.setID("Myfaces");
 		jsfLib.setName("Myfaces");
 		
 		ArchiveFile archiveFile = null;	
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/JSFLibraryRegistryTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/JSFLibraryRegistryTestCases.java
index c029578..d66ad9d 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/JSFLibraryRegistryTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/JSFLibraryRegistryTestCases.java
@@ -122,8 +122,8 @@
 		JSFLibraryRegistry jsfLibRegistry = JSFCoreUtilHelper.getNewJSFLibraryRegistry();
 		JSFLibrary lib = JSFCoreUtilHelper.constructJSFLib("lib", "testfiles/JSFLib", true, false);
 		jsfLibRegistry.addJSFLibrary(lib);
-		String libID = "myNewID";
-		lib.setID(libID);
+		String libID = "lib";
+//		lib.setID(libID);
 		Assert.assertEquals(lib, jsfLibRegistry.getJSFLibraryByID(libID));
 	}
 
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/MaintainDefaultImplementationAdapterTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/MaintainDefaultImplementationAdapterTestCases.java
index b7d782a..0431ead 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/MaintainDefaultImplementationAdapterTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryregistry/MaintainDefaultImplementationAdapterTestCases.java
@@ -38,7 +38,7 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add impl
-		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "impl1", "testfiles/JSFLib", true, false);
+		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl1);
 		//test
 		Assert.assertEquals(impl1, registry.getDefaultImplementation());
@@ -48,10 +48,10 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add impl
-		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "impl1", "testfiles/JSFLib", true, false);
+		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl1);
 		//create and add impl
-		JSFLibrary impl2 = JSFCoreUtilHelper.constructJSFLib("impl2", "impl2", "testfiles/JSFLib", true, false);
+		JSFLibrary impl2 = JSFCoreUtilHelper.constructJSFLib("impl2", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl2);
 		//test
 		Assert.assertEquals(impl1, registry.getDefaultImplementation());
@@ -65,7 +65,7 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add impl
-		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "impl1", "testfiles/JSFLib", true, false);
+		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl1);
 		//test
 		Assert.assertEquals(impl1, registry.getDefaultImplementation());
@@ -79,7 +79,7 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add lib
-		JSFLibrary lib1 = JSFCoreUtilHelper.constructJSFLib("lib1", "lib1", "testfiles/JSFLib", false, false);
+		JSFLibrary lib1 = JSFCoreUtilHelper.constructJSFLib("lib1", "testfiles/JSFLib", false, false);
 		registry.addJSFLibrary(lib1);
 		//test
 		Assert.assertNull(registry.getDefaultImplementation());
@@ -93,10 +93,10 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add impl
-		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "impl1", "testfiles/JSFLib", true, false);
+		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl1);
 		//create and add impl
-		JSFLibrary impl2 = JSFCoreUtilHelper.constructJSFLib("impl2", "impl2", "testfiles/JSFLib", true, false);
+		JSFLibrary impl2 = JSFCoreUtilHelper.constructJSFLib("impl2", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl2);
 		//test
 		Assert.assertEquals(impl1, registry.getDefaultImplementation());
@@ -110,7 +110,7 @@
 		//get prepared registry
 		JSFLibraryRegistry registry = getPreparedJSFLibraryRegistry();
 		//create and add impl
-		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "impl1", "testfiles/JSFLib", true, false);
+		JSFLibrary impl1 = JSFCoreUtilHelper.constructJSFLib("impl1", "testfiles/JSFLib", true, false);
 		registry.addJSFLibrary(impl1);
 		//test
 		Assert.assertEquals(impl1, registry.getDefaultImplementation());
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/util/JSFCoreUtilHelper.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/util/JSFCoreUtilHelper.java
index 2cd4a4f..9e2d0de 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/util/JSFCoreUtilHelper.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/util/JSFCoreUtilHelper.java
@@ -39,7 +39,7 @@
 		String testData;		
 		String pathTestFiles = TestsPlugin.getInstallLocation().getPath() + "testfiles/";
 		JSFLibrary jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createJSFLibrary();
-		jsfLib.setID(id);
+//		jsfLib.setID(id);
 		jsfLib.setName(name);	
 		jsfLib.setImplementation(bImpl);
 		
@@ -134,7 +134,7 @@
 		JSFLibrary jsfLib = null;
 		if (isFakedPlugginLib){
 			jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createPluginProvidedJSFLibrary();
-			jsfLib.setID("fakePluginLib_"+name);
+//			jsfLib.setID("fakePluginLib_"+name);
 		}
 		else
 			jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createJSFLibrary();
@@ -167,27 +167,27 @@
 		return jsfLib;
 	}
 
-	/**
-	 * Creates a JSF Library from all the jars and zips found at the relative
-	 * path from this plugin.
-	 * 
-	 * @param ID
-	 * @param name
-	 * @param relPathToArchives
-	 * @param isImpl
-	 * @param isFakedPlugginLib 
-	 * @return JSFLibrary
-	 */
-	public static JSFLibrary constructJSFLib(
-			String ID,
-			String name,			
-			String relPathToArchives, 
-			boolean isImpl,
-			boolean isFakedPlugginLib) {
-
-		JSFLibrary jsfLib = constructJSFLib(name, relPathToArchives, isImpl, isFakedPlugginLib);
-		jsfLib.setID(ID);
-		return jsfLib;
-	}
+//	/**
+//	 * Creates a JSF Library from all the jars and zips found at the relative
+//	 * path from this plugin.
+//	 * 
+//	 * @param ID
+//	 * @param name
+//	 * @param relPathToArchives
+//	 * @param isImpl
+//	 * @param isFakedPlugginLib 
+//	 * @return JSFLibrary
+//	 */
+//	public static JSFLibrary constructJSFLib(
+//			String ID,
+//			String name,			
+//			String relPathToArchives, 
+//			boolean isImpl,
+//			boolean isFakedPlugginLib) {
+//
+//		JSFLibrary jsfLib = constructJSFLib(name, relPathToArchives, isImpl, isFakedPlugginLib);
+////		jsfLib.setID(ID);
+//		return jsfLib;
+//	}
 
 }
\ No newline at end of file
diff --git a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFProjectLibraryReferenceTestCases.java b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFProjectLibraryReferenceTestCases.java
index 80004de..03857aa 100644
--- a/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFProjectLibraryReferenceTestCases.java
+++ b/jsf/tests/org.eclipse.jst.jsf.core.tests/src/org/eclipse/jst/jsf/core/tests/jsflibraryconfig/JSFProjectLibraryReferenceTestCases.java
@@ -3,7 +3,7 @@
 import junit.framework.Assert;
 import junit.framework.TestCase;
 
-import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFProjectLibraryReference;
+import org.eclipse.jst.jsf.core.internal.jsflibraryconfig.JSFLibraryReference;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.ArchiveFile;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibrary;
 import org.eclipse.jst.jsf.core.internal.jsflibraryregistry.JSFLibraryRegistryFactory;
@@ -11,10 +11,10 @@
 
 public class JSFProjectLibraryReferenceTestCases extends TestCase {
 	private String JSF_NAME = "MockJSFLib";
-	private String JSF_ID = "123456789";
+//	private String JSF_ID = "123456789";
 	private boolean isImpl = false;
 	private JSFLibrary jsfLib = null;
-	private JSFProjectLibraryReference jsfLibRef = null;
+	private JSFLibraryReference jsfLibRef = null;
 	
 	public JSFProjectLibraryReferenceTestCases(String name) {
 		super(name);
@@ -24,11 +24,11 @@
 		super.setUp();
 		
 		jsfLib = JSFLibraryRegistryFactory.eINSTANCE.createJSFLibrary();		
-		jsfLib.setID(JSF_ID);
+//		jsfLib.setID(JSF_ID);
 		jsfLib.setName(JSF_NAME);
 		jsfLib.setImplementation(false);
 				
-		jsfLibRef = new JSFProjectLibraryReference(jsfLib, 
+		jsfLibRef = new JSFLibraryReference(jsfLib, 
 	   											   true,	// selected 
 												   true);	// to be deployed
 	}
@@ -41,21 +41,21 @@
 	}
 
 	/*
 	 * General test class for JSFProjectLibraryReference class
 	 */
 	public void testJSFProjectLibraryReference() {		
-		JSFProjectLibraryReference jsfLibRef_ = new JSFProjectLibraryReference(jsfLib, true, true);
+		JSFLibraryReference jsfLibRef_ = new JSFLibraryReference(jsfLib, true, true);
 		
 		Assert.assertNotNull(jsfLibRef_);		
 		Assert.assertTrue(jsfLibRef_.isSelected());
 		Assert.assertTrue(jsfLibRef_.isCheckedToBeDeployed());		
 		Assert.assertTrue(JSF_NAME.equals(jsfLibRef_.getName()));
-		Assert.assertTrue(JSF_ID.equals(jsfLibRef_.getID()));
+		Assert.assertTrue(JSF_NAME.equals(jsfLibRef_.getID()));
 		Assert.assertTrue(isImpl == jsfLibRef_.isImplementation());
 	}		
 	
 	/*
-	 * test method for JSFProjectLibraryReference.getLibrary()
+	 * test method for JSFLibraryReference.getLibrary()
 	 */
 	public void testGetLibrary() {
 		Assert.assertNotNull(jsfLibRef);
@@ -63,19 +63,19 @@
 	}
 
 	/*
-	 * test method for JSFProjectLibraryReference.isCheckedToBeDeployed()
+	 * test method for JSFLibraryReference.isCheckedToBeDeployed()
 	 */
 	public void testIsCheckedToBeDeployed() {
-		JSFProjectLibraryReference jsfLibRef_ = new JSFProjectLibraryReference(jsfLib, true, true);
+		JSFLibraryReference jsfLibRef_ = new JSFLibraryReference(jsfLib, true, true);
 		Assert.assertNotNull(jsfLibRef_);		
 		Assert.assertTrue(jsfLibRef_.isCheckedToBeDeployed());
 	}
 
 	/*
-	 * test method for JSFProjectLibraryReference.setSelected()
+	 * test method for JSFLibraryReference.setSelected()
 	 */
 	public void testSetSelected() {
-		JSFProjectLibraryReference jsfLibRef_ = new JSFProjectLibraryReference(jsfLib, true, true);
+		JSFLibraryReference jsfLibRef_ = new JSFLibraryReference(jsfLib, true, true);
 		Assert.assertNotNull(jsfLibRef_);		
 		
 		Assert.assertTrue(jsfLibRef_.isSelected());
@@ -85,14 +85,14 @@
 	}
 
 	/*
-	 * test method for JSFProjectLibraryReference.isImplementation()
+	 * test method for JSFLibraryReference.isImplementation()
 	 */
 	public void testIsImplementation() {
 		Assert.assertFalse(jsfLibRef.isImplementation());
 	}
 
 	/*
-	 * test method for JSFProjectLibraryReference.getArchiveFiles()
+	 * test method for JSFLibraryReference.getArchiveFiles()
 	 */	
 	public void testGetArchiveFiles() {
 		String path2TestJAR = TestsPlugin.getInstallLocation().getPath() + "testfiles/faces-all-bogus.jar";
@@ -41,21 +41,21 @@
 
 	/*
-	 * General test class for JSFProjectLibraryReference class
+	 * General test class for JSFLibraryReference class
 	 */
 	public void testJSFProjectLibraryReference() {		